==> webkitgtk-2.7.2.tar.xz: webkitgtk-2.7.2/Source/WebKit2/Shared/API/c/WKActionMenuTypes.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WKActionMenuTypes_h
#define WKActionMenuTypes_h

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

enum {
    kWKActionMenuNone = 0,
    kWKActionMenuLink,
    kWKActionMenuImage,
    kWKActionMenuDataDetectedItem,
    kWKActionMenuReadOnlyText,
    kWKActionMenuEditableText,
    kWKActionMenuEditableTextWithSuggestions,
    kWKActionMenuWhitespaceInEditableArea,
    kWKActionMenuVideo,
    kWKActionMenuMailtoLink
};
typedef uint32_t _WKActionMenuType;

#ifdef __cplusplus
}
#endif

#endif /* WKActionMenuTypes_h */

==> webkitgtk-2.8.5.tar.xz: webkitgtk-2.8.5/Source/WebKit2/Shared/API/c/WKActionMenuTypes.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WKActionMenuTypes_h
#define WKActionMenuTypes_h

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

enum {
    kWKActionMenuNone = 0,
    kWKActionMenuLink,
    kWKActionMenuImage,
    kWKActionMenuDataDetectedItem,
    kWKActionMenuReadOnlyText,
    kWKActionMenuEditableText,
    kWKActionMenuEditableTextWithSuggestions,
    kWKActionMenuWhitespaceInEditableArea,
    kWKActionMenuVideo,
    kWKActionMenuMailtoLink,
    kWKActionMenuTelLink
};
typedef uint32_t _WKActionMenuType;

#ifdef __cplusplus
}
#endif

#endif /* WKActionMenuTypes_h */
